<?php

namespace Hospital\Doctor\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hospital\Doctor\Models\Doctor;

class DoctorPolicy
{

    /**
     * Determine if the given user can view the doctor.
     *
     * @param UserPolicy $user
     * @param Doctor $doctor
     *
     * @return bool
     */
    public function view(UserPolicy $user, Doctor $doctor)
    {
        if ($user->canDo('doctor.doctor.view') && $user->isAdmin()) {
            return true;
        }

        return $doctor->user_id == user_id() && $doctor->user_type == user_type();
    }

    /**
     * Determine if the given user can create a doctor.
     *
     * @param UserPolicy $user
     * @param Doctor $doctor
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('doctor.doctor.create');
    }

    /**
     * Determine if the given user can update the given doctor.
     *
     * @param UserPolicy $user
     * @param Doctor $doctor
     *
     * @return bool
     */
    public function update(UserPolicy $user, Doctor $doctor)
    {
        if ($user->canDo('doctor.doctor.edit') && $user->isAdmin()) {
            return true;
        }

        return $doctor->user_id == user_id() && $doctor->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given doctor.
     *
     * @param UserPolicy $user
     * @param Doctor $doctor
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Doctor $doctor)
    {
        return $doctor->user_id == user_id() && $doctor->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given doctor.
     *
     * @param UserPolicy $user
     * @param Doctor $doctor
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Doctor $doctor)
    {
        if ($user->canDo('doctor.doctor.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given doctor.
     *
     * @param UserPolicy $user
     * @param Doctor $doctor
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Doctor $doctor)
    {
        if ($user->canDo('doctor.doctor.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
