<?php

namespace Hospital\Doctor\Providers;

use Illuminate\Support\ServiceProvider;

class DoctorServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'doctor');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'doctor');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('hospital.doctor', function ($app) {
            return $this->app->make('Hospital\Doctor\Doctor');
        });

                // Bind Doctor to repository
        $this->app->bind(
            'Hospital\Doctor\Interfaces\DoctorRepositoryInterface',
            \Hospital\Doctor\Repositories\Eloquent\DoctorRepository::class
        );

        $this->app->register(\Hospital\Doctor\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Hospital\Doctor\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['hospital.doctor'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('hospital/doctor.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/doctor')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/doctor')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
